=========
CHANGELOG
=========

0.7.0 (06-11-2020)
------------------

+ Added support up until Wagtail 2.11
+ Dropped support for Wagtail < 2.7

0.6.0 (08-05-2020)
------------------
+ Added support for Wagtail 2.9
+ Verify support for Wagtail 2.8
+ Dropped support for Wagtail < 2.3

0.5.1 (14-04-2020)
------------------
+ Add changelog to manifest which started throwing error

0.5.0 (09-04-2020)
------------------
+ Add property `wagtailformblocks_autoregister` to skip automatic registration

0.4.0 (18-07-2019)
------------------
+ Update support for Django Recaptcha to v2, dropped support for v1

0.3.1 (03-10-2018)
------------------
+ Added succes message field missing from the configuration

0.3.0 (31-08-2018)
------------------
+ Added support for Wagtail 2.x
+ Dropped support for Wagtail 1.x

0.2.0 (09-08-2017)
------------------
+ Dropped support for Wagtail 1.4, 1.5, 1.6, 1.7
+ Added support for Wagtail 1.8 (LTS), 1.9, 1.10 and 1.11 (Oktay Altay)

0.1.4 (24-01-2017)
------------------
+ Fixed form selector in formhandler.js (Marco Westerhof)

0.1.3 (28-10-2016)
------------------
+ Add `django-recaptcha` field when available.

0.1.2 (07-10-2016)
------------------
+ Added CSRF support in the example jQuery form handler

0.1.1 (11-09-2016)
------------------
+ Updated license model to BSD
+ Update documentation on how to install (Rubén Colina)

0.1.0 (01-09-2016)
------------------
+ First implementation
